#!/system/bin/sh
##########################################################################################
#
# Magisk Boot Image Patcher
# by topjohnwu
#
# This script should be placed in a directory with the following files:
#
# File name       type      Description
#
# boot_patch.sh   script    A script to patch boot. Expect path to boot image as parameter.
#               (this file) The script will use binaries and files in its same directory
#                           to complete the patching process
# monogisk        binary    The monolithic binary to replace /init
# magiskboot      binary    A tool to unpack boot image, decompress ramdisk, extract ramdisk
#                           , and patch the ramdisk for Magisk support
# chromeos        folder    This folder should store all the utilities and keys to sign
#               (optional)  a chromeos device, used in the tablet Pixel C
#
# If the script is not running as root, then the input boot image should be a stock image
# or have a backup included in ramdisk internally, since we cannot access the stock boot
# image placed under /data we've created when previously installed
#
##########################################################################################

##########################################################################################
# Initialization
##########################################################################################

BOOTDIR="$1"

KEEPVERITY=false
HIGHCOMP=false
KEEPFORCEENCRYPT=false

. $2/util_functions.sh

chmod -R 755 .

# Extract magisk if doesn't exist
[ -e magisk ] || ./magiskinit -x magisk magisk

cp $BOOTDIR/kernel ./kernel
cp $BOOTDIR/ramdisk ./ramdisk.cpio.gz

gunzip ./ramdisk.cpio.gz
cp ramdisk.cpio ramdisk.cpio.orig

SHA1=`./magiskboot --cpio ramdisk.cpio.orig sha1 2>/dev/null`

##########################################################################################
# Ramdisk patches
##########################################################################################

ui_print "- Patching ramdisk"

./magiskboot --cpio ramdisk.cpio \
'add 750 init magiskinit' \
"magisk ramdisk.cpio.orig $HIGHCOMP $KEEPVERITY $KEEPFORCEENCRYPT $SHA1"

##########################################################################################
# Binary patches
##########################################################################################

if [ -f kernel ]; then
  # Remove Samsung RKP in stock kernel
  ./magiskboot --hexpatch kernel \
  49010054011440B93FA00F71E9000054010840B93FA00F7189000054001840B91FA00F7188010054 \
  A1020054011440B93FA00F7140020054010840B93FA00F71E0010054001840B91FA00F7181010054

  # skip_initramfs -> want_initramfs
  ./magiskboot --hexpatch kernel \
  736B69705F696E697472616D6673 \
  77616E745F696E697472616D6673
fi

##########################################################################################
# Repack and replace
##########################################################################################

gzip ramdisk.cpio

ui_print "- Extending boot partition"
umount /dev/block/sda1
./parted /dev/block/sda resizepart 1 16MB
e2fsck -fy /dev/block/sda1
resize2fs /dev/block/sda1
mount /dev/block/sda1 $BOOTDIR

ui_print "- Replacing files"
cp ramdisk.cpio.gz $BOOTDIR/ramdisk
cp kernel $BOOTDIR/kernel

./magiskboot --cleanup
