#MAGISK
##########################################################################################
#
# Magisk Flash Script
# by topjohnwu
#
# This script will detect, construct the environment for Magisk
# It will then call boot_patch.sh to patch the boot image
#
##########################################################################################

##########################################################################################
# Preparation
##########################################################################################

# This path should work in any cases
TMPDIR=/data/local/tmp

INSTALLER=$TMPDIR/magisk
COMMONDIR=$INSTALLER/common
APK=$COMMONDIR/magisk.apk

# Default permissions
umask 022

OUTFD=$2

# Load utility fuctions
. $COMMONDIR/util_functions.sh

get_outfd

##########################################################################################
# Detection
##########################################################################################

ui_print "************************"
ui_print "* Magisk v$MAGISK_VER Installer"
ui_print "************************"

BOOTDIR=$TMPDIR/boot
mkdir $BOOTDIR
mount /dev/block/sda1 $BOOTDIR

ui_print "- Device platform: x86"

BINDIR=$INSTALLER/x86
chmod -R 755 $BINDIR

# Check if system root is installed and remove
remove_system_su

##########################################################################################
# Environment
##########################################################################################

ui_print "- Constructing environment"

MAGISKBIN=/data/adb/magisk
run_migrations

# Copy required files
rm -rf $MAGISKBIN/* 2>/dev/null
mkdir -p $MAGISKBIN 2>/dev/null
cp -af $BINDIR/. $COMMONDIR/. $MAGISKBIN
chmod -R 755 $MAGISKBIN

##########################################################################################
# Boot patching
##########################################################################################

cd $MAGISKBIN

# Source the boot patcher
$COMMONDIR/boot_patch.sh "$BOOTDIR" "$COMMONDIR"

umount $BOOTDIR
rm -rf $INSTALLER
rm -rf $BOOTDIR

ui_print "- Done"
exit 0
